@@ -1,6 +1,6 @@
 {- management of the git-annex branch
  -
- - Copyright 2011 Joey Hess <joey@kitenet.net>
+ - Copyright 2011-2012 Joey Hess <joey@kitenet.net>
  -
  - Licensed under the GNU GPL version 3 or higher.
  -}
@@ -18,6 +18,7 @@ module Annex.Branch (
 	get,
 	change,
 	commit,
+	stage,
 	files,
 ) where
 
@@ -32,7 +33,7 @@ import qualified Git.Command
 import qualified Git.Ref
 import qualified Git.Branch
 import qualified Git.UnionMerge
-import qualified Git.HashObject
+import Git.HashObject
 import qualified Git.Index
 import Annex.CatFile
 
@@ -114,14 +115,14 @@ updateTo pairs = do
 	-- ensure branch exists, and get its current ref
 	branchref <- getBranch
 	-- check what needs updating before taking the lock
-	dirty <- journalDirty
+	dirty <- unCommitted
 	(refs, branches) <- unzip <$> filterM isnewer pairs
-	if (not dirty && null refs)
+	if not dirty && null refs
 		then updateIndex branchref
 		else withIndex $ lockJournal $ do
 			when dirty stageJournal
 			let merge_desc = if null branches
-				then "update" 
+				then "update"
 				else "merging " ++
 					unwords (map Git.Ref.describe branches) ++ 
 					" into " ++ show name
@@ -172,7 +173,7 @@ get' staleok file = fromcache =<< getCache file
  - modifes the current content of the file on the branch.
  -}
 change :: FilePath -> (String -> String) -> Annex ()
-change file a = lockJournal $ getStale file >>= return . a >>= set file
+change file a = lockJournal $ a <$> getStale file >>= set file
 
 {- Records new content of a file into the journal and cache. -}
 set :: FilePath -> String -> Annex ()
@@ -182,15 +183,21 @@ set file content = do
 
 {- Stages the journal, and commits staged changes to the branch. -}
 commit :: String -> Annex ()
-commit message = whenM journalDirty $ lockJournal $ do
+commit message = whenM unCommitted $ lockJournal $ do
 	stageJournal
 	ref <- getBranch
 	withIndex $ commitBranch ref message [fullname]
 
+{- Stages the journal, not making a commit to the branch. -}
+stage :: Annex ()
+stage = whenM journalDirty $ lockJournal $ do
+	stageJournal
+	setUnCommitted
+
 {- Commits the staged changes in the index to the branch.
  - 
  - Ensures that the branch's index file is first updated to the state
- - of the brannch at branchref, before running the commit action. This
+ - of the branch at branchref, before running the commit action. This
  - is needed because the branch may have had changes pushed to it, that
  - are not yet reflected in the index.
  -
@@ -213,6 +220,7 @@ commitBranch branchref message parents = do
 	parentrefs <- commitparents <$> catObject committedref
 	when (racedetected branchref parentrefs) $
 		fixrace committedref parentrefs
+	setCommitted
 	where
 		-- look for "parent ref" lines and return the refs
 		commitparents = map (Git.Ref . snd) . filter isparent .
@@ -301,19 +309,39 @@ setIndexSha ref = do
         lock <- fromRepo gitAnnexIndexLock
 	liftIO $ writeFile lock $ show ref ++ "\n"
 
+{- Checks if there are uncommitted changes in the branch's index or journal. -}
+unCommitted :: Annex Bool
+unCommitted = do
+	d <- liftIO . doesFileExist =<< fromRepo gitAnnexIndexDirty
+	if d
+		then return d
+		else journalDirty
+
+setUnCommitted :: Annex ()
+setUnCommitted = do
+	file <- fromRepo gitAnnexIndexDirty
+	liftIO $ writeFile file "1"
+
+setCommitted :: Annex ()
+setCommitted = do
+	file <- fromRepo gitAnnexIndexDirty
+	_ <- liftIO $ tryIO $ removeFile file
+	return ()
+
 {- Stages the journal into the index. -}
 stageJournal :: Annex ()
 stageJournal = do
 	fs <- getJournalFiles
 	g <- gitRepo
 	withIndex $ liftIO $ do
-		let dir = gitAnnexJournalDir g
-		let paths = map (dir </>) fs
-		(shas, cleanup) <- Git.HashObject.hashFiles paths g
-		Git.UnionMerge.update_index g $
-			index_lines shas (map fileJournal fs)
-		cleanup
-		mapM_ removeFile paths
+		h <- hashObjectStart g
+		Git.UnionMerge.stream_update_index g
+			[genstream (gitAnnexJournalDir g) h fs]
+		hashObjectStop h
 	where
-		index_lines shas = map genline . zip shas
-		genline (sha, file) = Git.UnionMerge.update_index_line sha file
+		genstream dir h fs streamer = forM_ fs $ \file -> do
+			let path = dir </> file
+			sha <- hashFile h path
+			_ <- streamer $ Git.UnionMerge.update_index_line
+				sha (fileJournal file)
+			removeFile path
