@@ -8,7 +8,6 @@
 module Annex.Version where
 
 import Common.Annex
-import qualified Git.Config
 import Config
 
 type Version = String
@@ -26,7 +25,7 @@ versionField :: String
 versionField = "annex.version"
 
 getVersion :: Annex (Maybe Version)
-getVersion = handle <$> fromRepo (Git.Config.get versionField "")
+getVersion = handle <$> getConfig versionField ""
 	where
 		handle [] = Nothing
 		handle v = Just v
