@@ -7,8 +7,10 @@
 
 module Command.Commit where
 
+import Common.Annex
 import Command
 import qualified Annex.Branch
+import qualified Git
 
 def :: [Command]
 def = [command "commit" paramNothing seek
@@ -20,4 +22,8 @@ seek = [withNothing start]
 start :: CommandStart
 start = next $ next $ do
 	Annex.Branch.commit "update"
+	_ <- runhook =<< (inRepo $ Git.hookPath "annex-content")
 	return True
+	where
+		runhook (Just hook) = liftIO $ boolSystem hook []
+		runhook Nothing = return True
