@@ -28,6 +28,7 @@ import qualified Command.Copy
 import qualified Command.Get
 import qualified Command.FromKey
 import qualified Command.DropKey
+import qualified Command.ReKey
 import qualified Command.Reinject
 import qualified Command.Fix
 import qualified Command.Init
@@ -80,6 +81,7 @@ cmds = concat
 	, Command.Dead.def
 	, Command.FromKey.def
 	, Command.DropKey.def
+	, Command.ReKey.def
 	, Command.Fix.def
 	, Command.Fsck.def
 	, Command.Unused.def
@@ -119,7 +121,7 @@ options = Option.common ++
 		"skip files not using a key-value backend"
 	] ++ Option.matcher
 	where
-		setnumcopies v = Annex.changeState $ \s -> s {Annex.forcenumcopies = readMaybe v }
+		setnumcopies v = Annex.changeState $ \s -> s {Annex.forcenumcopies = readish v }
 		setgitconfig :: String -> Annex ()
 		setgitconfig v = do
 			newg <- inRepo $ Git.Config.store v
