@@ -57,6 +57,7 @@ gen' r u c cst =
 			removeKey = remove this,
 			hasKey = checkPresent this,
 			hasKeyCheap = False,
+			whereisKey = Nothing,
 			config = c,
 			repo = r,
 			remotetype = remote
@@ -143,9 +144,7 @@ storeHelper (conn, bucket) r k file = do
 			case fromJust $ M.lookup "storageclass" $ fromJust $ config r of
 				"REDUCED_REDUNDANCY" -> REDUCED_REDUNDANCY
 				_ -> STANDARD
-		getsize = do
-			s <- liftIO $ getFileStatus file
-			return $ fileSize s
+		getsize = fileSize <$> (liftIO $ getFileStatus file)
 		
 		xheaders = filter isxheader $ M.assocs $ fromJust $ config r
 		isxheader (h, _) = "x-amz-" `isPrefixOf` h
@@ -162,8 +161,8 @@ retrieve r k f = s3Action r False $ \(conn, bucket) -> do
 retrieveCheap :: Remote -> Key -> FilePath -> Annex Bool
 retrieveCheap _ _ _ = return False
 
-retrieveEncrypted :: Remote -> (Cipher, Key) -> FilePath -> Annex Bool
-retrieveEncrypted r (cipher, enck) f = s3Action r False $ \(conn, bucket) -> do
+retrieveEncrypted :: Remote -> (Cipher, Key) -> Key -> FilePath -> Annex Bool
+retrieveEncrypted r (cipher, enck) _ f = s3Action r False $ \(conn, bucket) -> do
 	res <- liftIO $ getObject conn $ bucketKey r bucket enck
 	case res of
 		Right o -> liftIO $ 
@@ -272,26 +271,32 @@ s3Connection c = do
 {- S3 creds come from the environment if set. 
  - Otherwise, might be stored encrypted in the remote's config. -}
 s3GetCreds :: RemoteConfig -> Annex (Maybe (String, String))
-s3GetCreds c = do
-	ak <- getEnvKey s3AccessKey
-	sk <- getEnvKey s3SecretKey
-	if null ak || null sk
-		then do
+s3GetCreds c = maybe fromconfig (return . Just) =<< liftIO getenv
+	where
+		getenv = liftM2 (,)
+			<$> get s3AccessKey
+			<*> get s3SecretKey
+			where
+				get = catchMaybeIO . getEnv
+		setenv (ak, sk) = do
+			setEnv s3AccessKey ak True
+			setEnv s3SecretKey sk True
+		fromconfig = do
 			mcipher <- remoteCipher c
 			case (M.lookup "s3creds" c, mcipher) of
-				(Just encrypted, Just cipher) -> do
-					s <- liftIO $ withDecryptedContent cipher
-						(return $ L.pack $ fromB64 encrypted)
-						(return . L.unpack)
-					let [ak', sk', _rest] = lines s
-					liftIO $ do
-						setEnv s3AccessKey ak True
-						setEnv s3SecretKey sk True
-					return $ Just (ak', sk')
+				(Just s3creds, Just cipher) ->
+					liftIO $ decrypt s3creds cipher
 				_ -> return Nothing
-		else return $ Just (ak, sk)
-	where
-		getEnvKey s = liftIO $ catchDefaultIO (getEnv s) ""
+		decrypt s3creds cipher = do
+			creds <- lines <$>
+				withDecryptedContent cipher
+					(return $ L.pack $ fromB64 s3creds)
+					(return . L.unpack)
+			case creds of
+				[ak, sk] -> do
+					setenv (ak, sk)
+					return $ Just (ak, sk)
+				_ -> do error "bad s3creds"
 
 {- Stores S3 creds encrypted in the remote's config if possible. -}
 s3SetCreds :: RemoteConfig -> Annex RemoteConfig
