@@ -14,11 +14,9 @@ module Seek where
 import Common.Annex
 import Types.Command
 import Types.Key
-import Backend
 import qualified Annex
 import qualified Git
 import qualified Git.LsFiles as LsFiles
-import qualified Git.CheckAttr
 import qualified Limit
 import qualified Option
 
@@ -28,26 +26,12 @@ seekHelper a params = inRepo $ \g -> runPreserveOrder (`a` g) params
 withFilesInGit :: (FilePath -> CommandStart) -> CommandSeek
 withFilesInGit a params = prepFiltered a $ seekHelper LsFiles.inRepo params
 
-withAttrFilesInGit :: String -> ((FilePath, String) -> CommandStart) -> CommandSeek
-withAttrFilesInGit attr a params = do
-	files <- seekHelper LsFiles.inRepo params
-	prepFilteredGen a fst $ inRepo $ Git.CheckAttr.lookup attr files
-
-withNumCopies :: (Maybe Int -> FilePath -> CommandStart) -> CommandSeek
-withNumCopies a params = withAttrFilesInGit "annex.numcopies" go params
-	where
-		go (file, v) = a (readMaybe v) file
-
-withBackendFilesInGit :: (BackendFile -> CommandStart) -> CommandSeek
-withBackendFilesInGit a params =
-	prepBackendPairs a =<< seekHelper LsFiles.inRepo params
-
-withFilesNotInGit :: (BackendFile -> CommandStart) -> CommandSeek
+withFilesNotInGit :: (FilePath -> CommandStart) -> CommandSeek
 withFilesNotInGit a params = do
 	{- dotfiles are not acted on unless explicitly listed -}
 	files <- filter (not . dotfile) <$> seek ps
 	dotfiles <- if null dotps then return [] else seek dotps
-	prepBackendPairs a $ preserveOrder params (files++dotfiles)
+	prepFiltered a $ return $ preserveOrder params (files++dotfiles)
 	where
 		(dotps, ps) = partition dotfile params
 		seek l = do
@@ -61,24 +45,29 @@ withWords a params = return [a params]
 withStrings :: (String -> CommandStart) -> CommandSeek
 withStrings a params = return $ map a params
 
+withPairs :: ((String, String) -> CommandStart) -> CommandSeek
+withPairs a params = return $ map a $ pairs [] params
+	where
+		pairs c [] = reverse c
+		pairs c (x:y:xs) = pairs ((x,y):c) xs
+		pairs _ _ = error "expected pairs"
+
 withFilesToBeCommitted :: (String -> CommandStart) -> CommandSeek
 withFilesToBeCommitted a params = prepFiltered a $
 	seekHelper LsFiles.stagedNotDeleted params
 
-withFilesUnlocked :: (BackendFile -> CommandStart) -> CommandSeek
+withFilesUnlocked :: (FilePath -> CommandStart) -> CommandSeek
 withFilesUnlocked = withFilesUnlocked' LsFiles.typeChanged
 
-withFilesUnlockedToBeCommitted :: (BackendFile -> CommandStart) -> CommandSeek
+withFilesUnlockedToBeCommitted :: (FilePath -> CommandStart) -> CommandSeek
 withFilesUnlockedToBeCommitted = withFilesUnlocked' LsFiles.typeChangedStaged
 
-withFilesUnlocked' :: ([FilePath] -> Git.Repo -> IO [FilePath]) -> (BackendFile -> CommandStart) -> CommandSeek
+withFilesUnlocked' :: ([FilePath] -> Git.Repo -> IO [FilePath]) -> (FilePath -> CommandStart) -> CommandSeek
 withFilesUnlocked' typechanged a params = do
 	-- unlocked files have changed type from a symlink to a regular file
-	top <- fromRepo Git.workTree
 	typechangedfiles <- seekHelper typechanged params
-	unlockedfiles <- liftIO $ filterM notSymlink $
-		map (\f -> top ++ "/" ++ f) typechangedfiles
-	prepBackendPairs a unlockedfiles
+	let unlockedfiles = liftIO $ filterM notSymlink typechangedfiles
+	prepFiltered a unlockedfiles
 
 withKeys :: (Key -> CommandStart) -> CommandSeek
 withKeys a params = return $ map (a . parse) params
@@ -107,20 +96,13 @@ withNothing _ _ = error "This command takes no parameters."
 
 
 prepFiltered :: (FilePath -> CommandStart) -> Annex [FilePath] -> Annex [CommandStart]
-prepFiltered a = prepFilteredGen a id
-
-prepBackendPairs :: (BackendFile -> CommandStart) -> CommandSeek
-prepBackendPairs a fs = prepFilteredGen a snd (chooseBackends fs)
-
-prepFilteredGen :: (b -> CommandStart) -> (b -> FilePath) -> Annex [b] -> Annex [CommandStart]
-prepFilteredGen a d fs = do
+prepFiltered a fs = do
 	matcher <- Limit.getMatcher
 	map (proc matcher) <$> fs
 	where
-		proc matcher v = do
-			let f = d v
+		proc matcher f = do
 			ok <- matcher f
-			if ok then a v else return Nothing
+			if ok then a f else return Nothing
 
 notSymlink :: FilePath -> IO Bool
 notSymlink f = liftIO $ not . isSymbolicLink <$> getSymbolicLinkStatus f
