@@ -9,6 +9,10 @@ import System.Environment
 
 import Common
 import qualified Git.UnionMerge
+import qualified Git.Config
+import qualified Git.Construct
+import qualified Git.Branch
+import qualified Git.Index
 import qualified Git
 
 header :: String
@@ -24,9 +28,7 @@ setup :: Git.Repo -> IO ()
 setup = cleanup -- idempotency
 
 cleanup :: Git.Repo -> IO ()
-cleanup g = do
-	e' <- doesFileExist (tmpIndex g)
-	when e' $ removeFile (tmpIndex g)
+cleanup g = whenM (doesFileExist $ tmpIndex g) $ removeFile $ tmpIndex g
 
 parseArgs :: IO [String]
 parseArgs = do
@@ -38,9 +40,9 @@ parseArgs = do
 main :: IO ()
 main = do
 	[aref, bref, newref] <- map Git.Ref <$> parseArgs
-	g <- Git.configRead =<< Git.repoFromCwd
-	_ <- Git.useIndex (tmpIndex g)
+	g <- Git.Config.read =<< Git.Construct.fromCurrent
+	_ <- Git.Index.override $ tmpIndex g
 	setup g
 	Git.UnionMerge.merge aref bref g
-	_ <- Git.commit "union merge" newref [aref, bref] g
+	_ <- Git.Branch.commit "union merge" newref [aref, bref] g
 	cleanup g
